@@ -9,15 +9,15 @@ class LikeModule(object):
 
 		'''
 		:param data: load the observational data, or (test_data)
-		:param noise: noise in the observational data, if any (optional)
 		:param nbins: numbers of k-bins at each data-set
+		:param noise: noise in the observational data, if any (optional)
+
 		'''
 
 		self.data = data
 		eye = np.eye(len(data))
-		cov1 = abs(data)/np.sqrt(nbins)
-		cov2 = abs(noise)/np.sqrt(nbins)
-		cov = cov1 + cov2
+		cov = abs(data)/np.sqrt(nbins)
+		cov = cov + abs(noise)
 		cov = eye*cov
 		self.cov_inv = np.linalg.inv(cov)
 		self.div = div
